@@ -1,8 +1,9 @@
 from flask_cors import CORS
 
 
-def error_handler(app):
-    CORS(app, supports_credentials=True)
+def error_handler(app, simple_cors: bool = True):
+    if simple_cors:
+        CORS(app, supports_credentials=True)
 
     @app.errorhandler(400)
     def handle_400_error(error):
